import { PaginatedList, PaginatedListLoadInfo } from "./PaginatedList";
/**
 * 여러 개의 PaginatedList 가 모여 구성된 전체 목록.
 *
 * PaginatedList 가 중간에 건너뛰지 않고 순서대로 추가되기를 기대하지만,
 * 만약 중간에 건너뛴 경우, undefined 로 채워져있는 것으로 취급된다.
 */
export declare class TotalList<T> {
    data: T[];
    totalCount: number;
    loadedCount: number;
    /**
     * `TotalList`에 `PaginatedList`를 추가한다.
     * @param list 추가할 `PaginatedList`
     */
    append(list?: PaginatedList<T>): void;
    /**
     * @return `TotalList`에 `PaginatedList`가 한 번도 추가된 적이 없으면 true, 그렇지 않으면 false
     */
    isBeforeInitialized(): boolean;
    /**
     * @return 데이터가 없으면 true. 초기화 전에는 empty 여부를 판단할 수 없으므로, false 를 리턴한다.
     */
    isEmpty(): boolean;
    /**
     * `TotalList`를 초기화 전 상태로 되돌린다.
     */
    clear(): void;
    /**
     * @return 더 로드할 데이터가 남아있으면 true, 그렇지 않으면 false. 초기화 전에는 false.
     */
    isMoreDataAvailable(): boolean;
    static copyOf<T>(src: TotalList<T>): TotalList<T>;
}
export declare type TotalListLoadInfo<T> = PaginatedListLoadInfo & {
    totalLoaded?: number;
    totalList?: TotalList<T>;
};
