import { App, Component } from "vue";
import { DynamicModalOptions, VueFinalModalProperty } from "vue-final-modal";
import { Router } from "vue-router";
declare type ModalProps = {
    [key in string]: unknown;
};
export declare type HistoryModalOptions = DynamicModalOptions & {
    showOnRefresh?: boolean;
};
export declare class HistoryModalManager {
    readonly modal: VueFinalModalProperty;
    readonly router: Router;
    private readonly historyModals;
    private unregisterRouterBeforeEach?;
    constructor(modal: VueFinalModalProperty, router: Router);
    initialize(): Promise<void>;
    destroy(): void;
    registerHistoryModal(modal: HistoryModal): Promise<void>;
    unregisterHistoryModal(modal: HistoryModal): void;
    private getRouteName;
    private handleRouterBeforeEach;
    private getModalNamesInHash;
    private findModals;
    private findHistoryModalHaving;
    /**
     * history modal 을 표시한다.
     * @param component modal 컴포넌트 이름 또는 객체
     * @param props 모달에 필요한 props
     */
    show(component: string | Component, props?: ModalProps): Promise<void>;
    private internalShowModal;
    /**
     * history modal 을 close 한다.
     * @param component modal 컴포넌트 이름 또는 객체
     */
    close(component: string | Component): Promise<void>;
    /**
     * 화면에 표시된 모든 modal 을 닫는다.
     * history modal 이 떠있는 경우, hash 도 제거된다.
     */
    closeAllModals(): Promise<void>;
    internalCloseModal(modalName: string, fullPathOnShow?: FullPathOnShow): Promise<void>;
    private waitFullPathChange;
    private synchronizeCurrent;
    private synchronizeModals;
}
declare type FullPathOnShow = {
    before: string;
    after: string;
};
export declare class HistoryModal {
    private readonly manager;
    private modalMap;
    private fullPathOnShow;
    constructor(manager: HistoryModalManager);
    initialize(): Promise<void>;
    destroy(): void;
    register(modal: HistoryModalOptions): void;
    getRegisteredModalNames(): string[];
    findRegisteredModals(modalNames: string[]): HistoryModalOptions[];
    hasModal(modalName: string): boolean;
    getModal(modalName: string): HistoryModalOptions | undefined;
    setFullPathOnShow(modalName: string, fullPath: FullPathOnShow): void;
    getFullPathOnShow(modalName: string): FullPathOnShow | undefined;
    private closedHandler;
}
/**
 * 반드시 `setup()` 함수 내에서 호출되어야 한다.
 * @param modals
 */
export declare const useHistoryModal: (...modals: HistoryModalOptions[]) => HistoryModalManager;
export declare type HistoryModalPluginOption = {
    modal: VueFinalModalProperty;
    router: Router;
};
/**
 * ```ts
 * createApp(GuideMain)
 *     .use(router)
 *     .use(ModalPlugin)
 *     .use(HistoryModalPlugin, {router, modal: ModalPlugin.modal})
 * ```
 */
export declare const HistoryModalPlugin: {
    install(app: App, option?: HistoryModalPluginOption): void;
};
export {};
