const urlUtil = {
  /**
   * `url` 이 absolute url 인지 확인한다.
   * @param url
   */
  isAbsoluteUrl(url?: string): boolean {
    return !!url &&
        (url.startsWith('http://') || url.startsWith('https://')
            || url.startsWith('mailto:') || url.startsWith('tel:'))
  },

  /**
   * `url` 이 relative url 이면 url 앞에 `prefix`를 붙인다.
   * absolute url 이면 url 을 그대로 리턴한다.
   * @param prefix
   * @param url
   */
  prependPrefixIfRelativeUrl(prefix: string, url?: string): string | undefined {
    if (!url) return undefined
    if (this.isAbsoluteUrl(url)) return url
    return prefix + url
  },

  /**
   * `url`이 내부 링크인지 확인한다.
   * `true`이면 이유를 리턴하고, `false`이면 `undefined`를 리턴한다.
   *  @param url
   */
  checkInternalLink(url: string): "RELATIVE_PATH" | "SAME_ORIGIN" | undefined {
    return !this.isAbsoluteUrl(url)
        ? "RELATIVE_PATH"
        : new URL(url).origin === new URL(location.href).origin
            ? "SAME_ORIGIN"
            : undefined
  },

  /**
   *  `targetUrl`과 `withUrl`를 비교하여, 같은 부분까지를 잘라내고 난 나머지를 리턴한다.
   *
   *  @example
   *  targetUrl: https://www.test.com/test
   *  withUrl: https://www.test.com/abc
   *  return "/test"
   *
   *  @param targetUrl
   *  @param withUrl
   *  @return remainedUrl
   */
  extractUrlDifferentPart(targetUrl: string, withUrl: string): string {
    return "/" + targetUrl.split("/")
        .filter((str, index) => str !== withUrl.split("/")[index])
        .join("/")
  }
}

export default urlUtil
